package top.lichx.webclassbackend.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.core.task.TaskExecutor;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.bind.annotation.*;
import top.lichx.webclassbackend.pojo.dto.ArticleInfoDTO;
import top.lichx.webclassbackend.pojo.vo.ArticleManagerInfoVO;
import top.lichx.webclassbackend.pojo.vo.VisibleUserInfoVO;
import top.lichx.webclassbackend.result.Result;
import top.lichx.webclassbackend.service.ArticleManagerService;
import top.lichx.webclassbackend.service.UserService;
import top.lichx.webclassbackend.util.AIUtil;
import top.lichx.webclassbackend.util.COSIO;

import java.time.format.DateTimeFormatter;

@Slf4j
@RestController
@RequestMapping("/article")
public class ArticleController {

    @Resource
    private ArticleManagerService articleManagerService;

    @Resource
    private UserService userService;

    @Resource
    private COSIO cosio;

    @Resource
    private AIUtil aiUtil;

    @Resource
    private TaskExecutor taskExecutor;

    @GetMapping("/page")
    public Result<IPage<ArticleManagerInfoVO>> getUserManagerInfoPage(@RequestParam int page, @RequestParam int size) {
        return Result.success("", articleManagerService.getArticleManagerInfoPage(page, size));
    }

    @GetMapping("/total")
    public Result<Integer> total() {
        return Result.success("", articleManagerService.getTotal());
    }

    @GetMapping("/userAvatar")
    public Result<?> getUserAvatar(@RequestParam String userId) {
        var user = userService.getUserByUserId(Integer.parseInt(userId));
        if (user == null)
            return Result.error("用户不存在");
        return Result.success("", cosio.GetFileLink(user.getAvatarPath()));
    }

    @GetMapping("/userInfo")
    public Result<?> getUserInfo(@RequestParam String userId) {
        var user = userService.getUserByUserId(Integer.parseInt(userId));
        if (user == null)
            return Result.error("用户不存在");
        var returnVO = new VisibleUserInfoVO();
        returnVO.setUserId("" + user.getId());
        returnVO.setUserName(user.getName());
        returnVO.setUserEmail(user.getEmail());
        returnVO.setUserAvatarPath(user.getAvatarPath());
        returnVO.setUserAmount(user.getAmount());
        returnVO.setUserBirthday(user.getBirth().format(DateTimeFormatter.ofPattern("yyyy-MM-dd")));
        return Result.success("", returnVO);
    }

    @PostMapping("/addArticle")
    public Result<?> addArticle(@RequestBody ArticleInfoDTO articleInfoDTO) {
        var id = articleManagerService.InsertArticleInfo(articleInfoDTO);
        UpdateArticleMainIdea(id, articleInfoDTO.getTitle(), articleInfoDTO.getContent());
        return Result.success("添加文章成功");
    }

    @PostMapping("/updateArticle")
    public Result<?> updateArticle(@RequestBody ArticleInfoDTO articleInfoDTO) {
        articleManagerService.UpdateArticleInfo(articleInfoDTO);
        UpdateArticleMainIdea(articleInfoDTO.getId(), articleInfoDTO.getTitle(), articleInfoDTO.getContent());
        return Result.success("更新文章成功");
    }

    @Async
    protected void UpdateArticleMainIdea(Integer articleId, String title, String content) {
        System.out.println("task start");
        taskExecutor.execute(() -> {
            var mainIdea = aiUtil.GetMainIdeaOfArticle(title, content);
            System.out.println(articleId);
            System.out.println(mainIdea);
            articleManagerService.UpdateArticleMainIdea(articleId, mainIdea);
        });
    }

    @GetMapping("/page/{authorName}")
    public Result<?> GetArticleById(@PathVariable String authorName, @RequestParam int page, @RequestParam int size) {
        var article = articleManagerService.GetArticlesByAuthorName(authorName, page, size);
        if (article == null)
            return Result.error("文章不存在");
        return Result.success("", article);
    }

    @GetMapping("/total/{authorName}")
    public Result<?> GetUserArticleTotal(@PathVariable String authorName) {
        var result = articleManagerService.GetArticleCountByAuthorName(authorName);
        return Result.success("", result);
    }

    @GetMapping("/deleteArticle")
    public Result<?> deleteArticle(@RequestParam String id) {
        articleManagerService.deleteArticleById(Integer.parseInt(id));
        return Result.success("删除文章成功");
    }
}
