package top.lichx.webclassbackend.controller;

import jakarta.annotation.Resource;
import jakarta.servlet.http.HttpServletRequest;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import top.lichx.webclassbackend.pojo.vo.VisibleUserInfoVO;
import top.lichx.webclassbackend.result.Result;
import top.lichx.webclassbackend.service.UserService;
import top.lichx.webclassbackend.util.COSIO;
import top.lichx.webclassbackend.util.JwtUtil;

import java.time.format.DateTimeFormatter;

@RestController
@RequestMapping("/user")
public class User {
    @Resource
    private UserService userService;

    @Resource
    private COSIO cosio;

    @GetMapping("/info")
    public Result<?> getUserInfo(HttpServletRequest request) {

        String cookieHeader = request.getHeader("Cookie");
        String token = null;
        if (cookieHeader != null) {
            String[] cookies = cookieHeader.split("; ");
            for (String cookie : cookies) {
                if (cookie.startsWith("Authorization=")) {
                    token = cookie.substring("Authorization=".length());
                    break;
                }
            }
        }
        token = token.substring(7); // 去掉 "Bearer " 前缀
        String username = JwtUtil.parseToken(token);

        var user = userService.getUserByUserName(username);
        if (user == null)
            return Result.error("用户不存在");
        var returnVO = new VisibleUserInfoVO();
        returnVO.setUserId("" + user.getId());
        returnVO.setUserName(user.getName());
        returnVO.setUserEmail(user.getEmail());
        returnVO.setUserAvatarPath(user.getAvatarPath());
        returnVO.setUserAmount(user.getAmount());
        returnVO.setUserBirthday(user.getBirth().format(DateTimeFormatter.ofPattern("yyyy-MM-dd")));
        return Result.success("", returnVO);
    }

    @GetMapping("/avatar")
    public Result<?> getUserAvatar(HttpServletRequest request) {
        String cookieHeader = request.getHeader("Cookie");
        String token = null;
        if (cookieHeader != null) {
            String[] cookies = cookieHeader.split("; ");
            for (String cookie : cookies) {
                if (cookie.startsWith("Authorization=")) {
                    token = cookie.substring("Authorization=".length());
                    break;
                }
            }
        }
        token = token.substring(7); // 去掉 "Bearer " 前缀
        String username = JwtUtil.parseToken(token);
        var user = userService.getUserByUserName(username);
        if (user == null)
            return Result.error("用户不存在");
        return Result.success("", cosio.GetFileLink(user.getAvatarPath()));
    }
}
