package top.lichx.webclassbackend.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import jakarta.annotation.Resource;
import org.springframework.web.bind.annotation.*;
import top.lichx.webclassbackend.pojo.dto.UserManagerDTO;
import top.lichx.webclassbackend.pojo.entity.UserManagerInfo;
import top.lichx.webclassbackend.result.Result;
import top.lichx.webclassbackend.service.UserManagerService;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;

@RestController
@RequestMapping("/userManager")
public class UserManager {
    @Resource
    private UserManagerService userManagerService;

    @PostMapping("/addUser")
    public Result<?> addUser(@RequestBody UserManagerDTO userManagerDTO)
    {
        var info = new UserManagerInfo();
        info.setId(userManagerService.getUserManagerInfoLastId());
        info.setName(userManagerDTO.getName());
        info.setDate(LocalDate.parse(userManagerDTO.getDate(), DateTimeFormatter.ISO_LOCAL_DATE));
        info.setProvince(userManagerDTO.getProvince());
        info.setCity(userManagerDTO.getCity());
        info.setAddress(userManagerDTO.getAddress());
        info.setZip(userManagerDTO.getZip());
        userManagerService.insertUserManagerInfo(info);
        return Result.success("添加用户成功");
    }

    @GetMapping("/page")
    public Result<IPage<UserManagerInfo>> getUserManagerInfoPage(@RequestParam int page, @RequestParam int size, @RequestParam String situation) {
        return Result.success("",userManagerService.getUserManagerInfoPage(page, size, situation));
    }

    @PostMapping("/updateUser")
    public Result<?>updateUser(@RequestBody UserManagerDTO userManagerDTO)
    {
        var info = new UserManagerInfo();
        info.setId(userManagerDTO.getId());
        info.setName(userManagerDTO.getName());
        info.setDate(LocalDate.parse(userManagerDTO.getDate(), DateTimeFormatter.ISO_LOCAL_DATE));
        info.setProvince(userManagerDTO.getProvince());
        info.setCity(userManagerDTO.getCity());
        info.setAddress(userManagerDTO.getAddress());
        info.setZip(userManagerDTO.getZip());
        userManagerService.updateUserManagerInfo(info);
        return Result.success("更新用户成功");
    }

    @GetMapping("/deleteUser")
    public Result<?> deleteUser(@RequestParam Integer id)
    {
        userManagerService.deleteUserManagerInfo(id);
        return Result.success("删除用户成功");
    }

    @GetMapping("/total")
    public Result<Integer> total(@RequestParam String situation)
    {
        return Result.success("", userManagerService.getTotal(situation));
    }
}
