package top.lichx.webclassbackend.interceptor;

import jakarta.servlet.http.Cookie;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import org.springframework.web.servlet.HandlerInterceptor;
import top.lichx.webclassbackend.util.JwtUtil;

@Component
@Slf4j
public class JwtInterceptor implements HandlerInterceptor {
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        String cookieHeader = request.getHeader("Cookie");
        String token = null;
        if (cookieHeader != null) {
            String[] cookies = cookieHeader.split("; ");
            for (String cookie : cookies) {
                if (cookie.startsWith("Authorization=")) {
                    token = cookie.substring("Authorization=".length());
                    break;
                }
            }
        }
        log.info("token:{}, URI:{}", token, request.getRequestURI());
        if (token == null || !token.startsWith("Bearer ")) {
            response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
            return false;
        }
        token = token.substring(7); // 去掉 "Bearer " 前缀
        String username = JwtUtil.parseToken(token);
        if (username == null) {
            response.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
            log.error("Token解析失败");
            return false;
        }
        request.setAttribute("username", username);
        log.info("用户 {} 访问了 {}", username, request.getRequestURI());
        return true;
    }
}