package top.lichx.webclassbackend.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import top.lichx.webclassbackend.mapper.articleManagerInfoMapper;
import top.lichx.webclassbackend.mapper.userMapper;
import top.lichx.webclassbackend.pojo.dto.ArticleInfoDTO;
import top.lichx.webclassbackend.pojo.entity.Article;
import top.lichx.webclassbackend.pojo.entity.User;
import top.lichx.webclassbackend.pojo.vo.ArticleManagerInfoVO;
import top.lichx.webclassbackend.service.ArticleManagerService;

import java.util.ArrayList;
import java.util.List;

@Service
public class ArticleManagerServiceImpl implements ArticleManagerService {
    @Resource
    private userMapper userMapper;
    @Resource
    private articleManagerInfoMapper articleManagerInfoMapper;

    @Override
    public IPage<ArticleManagerInfoVO> getArticleManagerInfoPage(int page, int size) {
        // 查询所有用户的 id 和 name
        List<User> users = userMapper.selectList(null);

        // 创建结果列表
        List<ArticleManagerInfoVO> result = new ArrayList<>();

        // 遍历用户列表
        for (User user : users) {
            String name = user.getName();

            // 查询 articleManagerInfoMapper 中 author 为 name 的数量
            int articleCount = articleManagerInfoMapper.selectCount(
                    new QueryWrapper<Article>().eq("author", name)
            ).intValue();

            // 将结果添加到列表中
            result.add(new ArticleManagerInfoVO(user.getId(), name, articleCount));
        }

        Page<ArticleManagerInfoVO> pageResult = new Page<>(page, size);
        pageResult.setRecords(result);
        pageResult.setTotal(users.size());
        return pageResult;
    }

    @Override
    public Integer getArticleManagerInfoLastId() {
        Article lastRecord = articleManagerInfoMapper.selectOne(
                new QueryWrapper<Article>().orderByDesc("id").last("LIMIT 1")
        );
        // 如果记录为空，返回 0，否则返回最后一条记录的 ID + 1
        return lastRecord == null ? 0 : lastRecord.getId() + 1;
    }

    @Override
    public Integer getTotal() {
        return userMapper.selectCount(null).intValue();
    }

    @Override
    public Integer InsertArticleInfo(ArticleInfoDTO articleInfoDTO)
    {
        Article article = new Article(getArticleManagerInfoLastId(), articleInfoDTO.getTitle(), articleInfoDTO.getAuthor(), articleInfoDTO.getContent());
        articleManagerInfoMapper.insert(article);
        return article.getId();
    }

    @Override
    public void UpdateArticleInfo(ArticleInfoDTO articleInfoDTO)
    {
        Article article = articleManagerInfoMapper.selectById(articleInfoDTO.getId());
        if(!article.getAuthor().equals(articleInfoDTO.getAuthor()))
        {
            throw new RuntimeException("作者不一致");
        }
        if (article != null) {
            article.setTitle(articleInfoDTO.getTitle());
            article.setContent(articleInfoDTO.getContent());
            article.setMainIdea("概述生成中...");
            articleManagerInfoMapper.updateById(article);
        }
    }

    @Override
    public void UpdateArticleMainIdea(Integer id, String mainIdea) {
        Article article = articleManagerInfoMapper.selectById(id);
        if (article != null) {
            article.setMainIdea(mainIdea);
            articleManagerInfoMapper.updateById(article);
        }
    }

    @Override
    public IPage<Article> GetArticlesByAuthorName(String authorName, Integer page, Integer size)
    {
        return articleManagerInfoMapper.selectPage(new Page<>(page, size),
                new QueryWrapper<Article>().eq("author", authorName));
    }

    @Override
    public Integer GetArticleCountByAuthorName(String authorName)
    {
        return articleManagerInfoMapper.selectCount(
                new QueryWrapper<Article>().eq("author", authorName)
        ).intValue();
    }

    @Override
    public void deleteArticleById(Integer id)
    {
        articleManagerInfoMapper.deleteById(id);
    }
}
