package top.lichx.webclassbackend.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import jakarta.annotation.Resource;
import org.springframework.stereotype.Service;
import top.lichx.webclassbackend.mapper.userMapper;
import top.lichx.webclassbackend.pojo.entity.User;
import top.lichx.webclassbackend.service.UserService;

@Service
public class UserServiceImpl implements UserService {
    @Resource
    private userMapper webclassMapper;

    @Override
    public void insertUser(User user) {
        webclassMapper.insert(user);
    }

    @Override
    public User getUserByUserName(String userName) {
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("name", userName);
        return webclassMapper.selectOne(queryWrapper);
    }

    @Override
    public User getUserByUserId(Integer userId) {
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("id", userId);
        return webclassMapper.selectOne(queryWrapper);
    }

    @Override
    public void changeUserPasswordByUserName(String userName, String password) {
        User user = getUserByUserName(userName);
        if (user != null) {
            user.setPassword(password);
            webclassMapper.updateById(user);
        }
    }

    @Override
    public User getUserByEmail(String email) {
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("email", email);
        return webclassMapper.selectOne(queryWrapper);
    }

    @Override
    public Integer getUserLastId() {
        User lastRecord = webclassMapper.selectOne(
                new QueryWrapper<User>().orderByDesc("id").last("LIMIT 1")
        );
        // 如果记录为空，返回 0，否则返回最后一条记录的 ID
        return lastRecord == null ? 0 : lastRecord.getId() + 1;
    }

    @Override
    public Integer getTotal() {
        return webclassMapper.selectCount(null).intValue();
    }
}
