package top.lichx.webclassbackend.util;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import jakarta.annotation.PostConstruct;
import lombok.AllArgsConstructor;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpMethod;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Component;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.client.RestTemplate;

import org.springframework.http.HttpHeaders;

import java.util.concurrent.CompletableFuture;

@Component
public class AIUtil {
    @Value("${deepseek.apikey}")
    private String apikey;
    @Value("${deepseek.apiurl}")
    private String apiurl;
    @Value("${deepseek.model}")
    private String model;

    public String GetMainIdeaOfArticle(String title, String content) {
        Message[] messages = new Message[] {
                new Message("system", "你需要总结出一篇文章的主要内容，写成概述，字数限制在100字以内，请尽量简洁明了，请直接输出观点，不要以：‘文章主要观点：’或‘文章概述：’开头，直接输出即可"),
                new Message("user", "文章标题：" + title + " 文章内容：" + content)
        };
        BodyData bodyData = new BodyData(messages, model, false);
        String jsonBody = new Gson().toJson(bodyData);
        String response = SendPostRequest(jsonBody);
        Gson gson = new Gson();
        JsonObject jsonObject = gson.fromJson(response, JsonObject.class);
        String mainIdea = jsonObject
                .getAsJsonArray("choices")
                .get(0)
                .getAsJsonObject()
                .getAsJsonObject("message")
                .get("content")
                .getAsString();
        return mainIdea;
    }

    private String SendPostRequest(String jsonBody) {
        RestTemplate restTemplate = new RestTemplate();
        HttpHeaders headers = new HttpHeaders();
        headers.set("Authorization", "Bearer " + apikey);
        headers.set("Content-Type", "application/json");
        HttpEntity<String> entity = new HttpEntity<String>(jsonBody, headers);
        ResponseEntity<String> responseEntity = restTemplate.exchange(apiurl, HttpMethod.POST, entity, String.class);
        if (responseEntity.getStatusCode().is2xxSuccessful()) {
            return responseEntity.getBody();
        } else {
            return "生成文章大意失败";
        }
    }
    @AllArgsConstructor
    class BodyData {
        Message[] messages;
        String model;
        boolean stream;
    }
    @AllArgsConstructor
    class Message {
        String role;
        String content;
    }

}
